@@ -7,6 +7,7 @@
  * Contract with IBM Corp.
  ****************************************************************************** */
 /* Copyright (c) 2020 Red Hat, Inc. */
+/* Copyright Contributors to the Open Cluster Management project */
 
 import _ from 'lodash';
 import crypto from 'crypto';
@@ -25,6 +26,8 @@ export default class KubeConnector {
     httpLib = requestLib,
     kubeApiEndpoint = process.env.API_SERVER_URL || 'https://kubernetes.default.svc',
     namespaces = isRequired('namespaces'),
+    clusterNamespaces,
+    userNamespaces,
     pollTimeout = config.get('hcmPollTimeout'),
     pollInterval = config.get('hcmPollInterval'),
     uid = Date.now,
@@ -33,6 +36,8 @@ export default class KubeConnector {
     this.http = httpLib;
     this.kubeApiEndpoint = kubeApiEndpoint;
     this.namespaces = namespaces;
+    this.clusterNamespaces = clusterNamespaces;
+    this.userNamespaces = userNamespaces;
     this.pollInterval = pollInterval;
     this.pollTimeout = pollTimeout;
     // to-do how to deal with this after removing all resource view
@@ -242,7 +247,7 @@ export default class KubeConnector {
       spec: {
         scope: {
           name: resourceName,
-          resource: apiGroup ? `${kind.toLowerCase()}.${version}.${apiGroup}` : `${kind.toLowerCase()}.${version}`,
+          resource: apiGroup ? `${kind.toLowerCase()}.${version}.${apiGroup}` : `${kind.toLowerCase()}`,
         },
       },
     };
