@@ -7,6 +7,7 @@
  * Contract with IBM Corp.
  ****************************************************************************** */
 /* Copyright (c) 2020 Red Hat, Inc. */
+/* Copyright Contributors to the Open Cluster Management project */
 
 import { gql } from 'apollo-server-express';
 import ComplianceModel from '../models/compliance';
@@ -15,7 +16,7 @@ export const typeDef = gql`
 type Policy implements K8sObject {
   detail: PolicyDetail
   # Possible values are: enforce, inform
-  enforcement: String
+  remediation: String
   metadata: Metadata
   rules: [PolicyRules]
   # Possible values are: compliant, notcompliant, invalid
@@ -133,7 +134,7 @@ export const resolver = {
   },
   Policy: {
     detail: (parent) => ComplianceModel.resolvePolicyDetails(parent),
-    enforcement: (parent) => ComplianceModel.resolvePolicyEnforcement(parent),
+    remediation: (parent) => ComplianceModel.resolvePolicyRemediation(parent),
     roleTemplates: (parent) => ComplianceModel.resolvePolicyTemplates(parent, 'role-templates'),
     roleBindingTemplates: (parent) => ComplianceModel.resolvePolicyTemplates(parent, 'roleBinding-templates'),
     objectTemplates: (parent) => ComplianceModel.resolvePolicyTemplates(parent, 'object-templates'),
